==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_nb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=nb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Nettstedets URI', # MODIF
	'form_pet_aucune_signature' => 'Ingen signatur finnes for denne koden...', # MODIF
	'form_pet_confirmation' => 'Bekreft signaturen:',
	'form_pet_deja_signe' => 'Du har allerede signert teksten.',
	'form_pet_mail_confirmation' => 'Hallo,

Du ønsket å skrive under på:
@titre@.

Du la inn følgende informasjon:
    Navn: @nom_email@
    Vev-sted: @nom_site@ - @url_site@
@message@

VIKTIG...
For å bekrefte må du gå til
denne adressen for å bli godkjent:
    @url@

Tusen takk!
',
	'form_pet_nom_site2' => 'Nettstedets navn', # MODIF
	'form_pet_probleme_liens' => 'Vennligst rediger meldingen og fjern alle lenker.',
	'form_pet_probleme_technique' => 'Vi har et teknisk problem. Signaturer er ikke tilgjengelig. ',
	'form_pet_signature_validee' => 'Din signatur er godkjent. Takk.',
	'form_pet_site_deja_enregistre' => 'Nettstedet er allerede registrert',
	'form_pet_url_invalide' => 'Lenken du har skrevet inn er ikke gyldig.',
	'form_pet_votre_email' => 'Din epostadresse',
	'form_pet_votre_nom' => 'Navn eller kallenavn', # MODIF
	'form_pet_votre_site' => 'Dersom du har et vev-sted kan du skrive det her',

	// I
	'info_adresse_email' => 'EPOSTADRESSE:',
	'info_signature_supprimee' => 'Signatur slettet',
	'info_signature_supprimee_erreur' => 'Feil: det finnes ingen signatur som stemmer med denne koden ', # MODIF
	'info_site_web' => 'NETTSTED:',

	// L
	'lien_reponse_article' => 'Svar på artikkelen'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_nb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=nb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Aktiverer anmodningen',
	'bouton_radio_pas_petition' => 'Ingen anmodninger',
	'bouton_radio_petition_activee' => 'Anmodning aktivert',
	'bouton_radio_supprimer_petition' => 'Slett anmodning',

	// F
	'form_pet_adresse_site' => 'Nettstedets URI', # MODIF
	'form_pet_aucune_signature' => 'Ingen signatur finnes for denne koden...', # MODIF
	'form_pet_confirmation' => 'Bekreft signaturen:',
	'form_pet_deja_signe' => 'Du har allerede signert teksten.',
	'form_pet_mail_confirmation' => 'Hallo,

Du ønsket å skrive under på:
@titre@.

Du la inn følgende informasjon:
    Navn: @nom_email@
    Vev-sted: @nom_site@ - @url_site@
@message@

VIKTIG...
For å bekrefte må du gå til
denne adressen for å bli godkjent:
    @url@

Tusen takk!
',
	'form_pet_nom_site2' => 'Nettstedets navn', # MODIF
	'form_pet_probleme_liens' => 'Vennligst rediger meldingen og fjern alle lenker.',
	'form_pet_probleme_technique' => 'Vi har et teknisk problem. Signaturer er ikke tilgjengelig. ',
	'form_pet_signature_validee' => 'Din signatur er godkjent. Takk.',
	'form_pet_site_deja_enregistre' => 'Nettstedet er allerede registrert',
	'form_pet_url_invalide' => 'Lenken du har skrevet inn er ikke gyldig.',
	'form_pet_votre_email' => 'Din epostadresse',
	'form_pet_votre_nom' => 'Navn eller kallenavn', # MODIF
	'form_pet_votre_site' => 'Dersom du har et vev-sted kan du skrive det her',

	// I
	'info_adresse_email' => 'EPOSTADRESSE:',
	'info_signature_supprimee' => 'Signatur slettet',
	'info_signature_supprimee_erreur' => 'Feil: det finnes ingen signatur som stemmer med denne koden ', # MODIF
	'info_site_web' => 'NETTSTED:',

	// L
	'lien_reponse_article' => 'Svar på artikkelen'
);

?>
